J = 100; %Number of grid points 
x = 0:1/(J+1):1; %values of x at grid points
dx = 1/(J+1); %Spatial step
s = 0.99; % < 1 for stability
dt = sqrt(s)*dx; %Time step for stability

T = 30; %Final time
M = floor(T/dt); %Number of iterations

y=x(2:end-1);
f = y.*(1-y).*exp(-10*(y-0.5).^2); %Initial wave profile

ymin = min(f);
ymax = max(f);

un = [f(2:end),0]; %u(i+1)
up = [0,f(1:end-1)]; %u(i-1)
u_prev = f;
u = s*(un + up)/2 + (1-s)*f;

plot(x,[0,u,0]);
pause;
key_pressed=0;
set(gcf, 'KeyPressFcn', 'key_pressed=mod(key_pressed+1,2);')

%Press any key to stop/start simulation
for i=1:M
    
    un = [u(2:end),0]; %u(i+1)
    up = [0,u(1:end-1)]; %u(i-1)
    
    uxx = (un - 2*u + up)/dx^2;
    v = 2*u - u_prev + dt^2*uxx;
    u_prev = u;  %Update previous values of u
    u = v;  %Update current value of u
    
    %Draw u
    plot(x,[0,u,0]);  %Draw the string plus the fixed u=0 endpoints
    plot(x,[0,u,0]);
    ymin = min(min(u),ymin);
    ymax = max(max(u),ymax);
    ylim([ymin ymax]);
    drawnow;
    
    %Pause when key is pressed
    while key_pressed == 1
        pause(0.1);
    end
end
